from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetEmojiKeywordsLanguages(BaseModel):
    """
    functions.messages.GetEmojiKeywordsLanguages
    ID: 0x4e9963b2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetEmojiKeywordsLanguages', 'GetEmojiKeywordsLanguages'] = pydantic.Field(
        'functions.messages.GetEmojiKeywordsLanguages',
        alias='_'
    )

    lang_codes: list[str]
