from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputGameShortName(BaseModel):
    """
    types.InputGameShortName
    ID: 0xc331e80a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputGameShortName', 'InputGameShortName'] = pydantic.Field(
        'types.InputGameShortName',
        alias='_'
    )

    bot_id: "base.InputUser"
    short_name: str
