from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionTopicCreate(BaseModel):
    """
    types.MessageActionTopicCreate
    ID: 0xd999256
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionTopicCreate', 'MessageActionTopicCreate'] = pydantic.Field(
        'types.MessageActionTopicCreate',
        alias='_'
    )

    title: str
    icon_color: int
    icon_emoji_id: typing.Optional[int] = None
